@@ -1,8 +1,8 @@
 import click
 
-from gevault.admin import Admin
-from gevault.refresh import Refresh
-from gevault.users import Users
+from gevault.lib.admin import Admin
+from gevault.lib.refresh import Refresh
+from gevault.lib.users import Users
 
 @click.group()
 def main():
@@ -13,6 +13,7 @@ def main():
 @click.option('-c', '--config', default=None, required=False)
 @click.option('-s', '--server', default="default", required=False)
 def admin(**kwargs):
+    bad_function_check(kwargs["function"])
     admin_class = Admin(config_file=kwargs["config"], server_name=kwargs["server"])
     getattr(admin_class, kwargs["function"])()
 
@@ -22,6 +23,7 @@ def admin(**kwargs):
 @click.option('-c', '--config', default=None, required=False)
 @click.option('-s', '--server', default="default", required=False)
 def users(**kwargs):
+    bad_function_check(kwargs["function"])
     users_class = Users(config_file=kwargs["config"], server_name=kwargs["server"])
     getattr(users_class, kwargs["function"])(kwargs.get('user', None))
 
@@ -31,5 +33,9 @@ def users(**kwargs):
 def refresh(**kwargs):
     Refresh(config_file=kwargs["config"], server_name=kwargs["server"])
 
+def bad_function_check(function_name):
+    if function_name.startswith("_"):
+        raise Exception("Attempted access to protected function.  Stop it.")
+
 if __name__ == '__main__':
     main()
